ASN: ASN alphabet

Description Usage Format Author(s) Examples

Description

the amino acid alphabet (20 symbols), i.e. A, C, D, E, F, G, H, I, K, L, M, N, P, Q, R, S, T, V, W, Y

Usage

1

Format

An object of class Alphabet of length 4.

Author(s)

Martin Nettling

Examples

1

Example output

Loading required package: cba
Loading required package: grid
Loading required package: proxy

Attaching package: ‘proxy’

The following objects are masked from ‘package:stats’:

    as.dist, dist

The following object is masked from ‘package:base’:

    as.matrix

$chars
 [1] "A" "C" "D" "E" "F" "G" "H" "I" "K" "L" "M" "N" "P" "Q" "R" "S" "T" "V" "W"
[20] "Y"

$cols
 [1] "Light green" "Green"       "Dark green"  "Dark green"  "violet"     
 [6] "Light green" "DarkBlue"    "Blue"        "Orange"      "Blue"       
[11] "Blue"        "Dark green"  "Pink"        "Dark green"  "Orange"     
[16] "Red"         "Red"         "Blue"        "violet"      "violet"     

$size
[1] 20

$supportReverseComplement
[1] FALSE

attr(,"class")
[1] "Alphabet"

DiffLogo documentation built on Nov. 8, 2020, 6:09 p.m.